Macro rust_default::embed_exercise
source · macro_rules! embed_exercise { ($name:expr, $path:expr) => { ... }; }
macro that was used to embed exercise in source code
macro_rules! embed_exercise { ($name:expr, $path:expr) => { ... }; }
macro that was used to embed exercise in source code