Struct rust_default::RustExercise

source ·
pub struct RustExercise { /* private fields */ }
An exercise. It can be viewed as a collection of tests

Implementations

source

impl RustExercise

source

pub fn parse(file: &str) -> Result<Self, RustError>

Parse the following file in a valid exercise definition

source

pub async fn generate_files( self, solution: String, ) -> Result<RustGeneratedFiles, RustError>

Load directly from file. Path must be a valid path pointing to a local file it generates file, getting reading for compilation