Struct rust_default::RustGeneratedFiles

source ·
pub struct RustGeneratedFiles {
    pub files: HashMap<String, (String, f64)>,
}
Rust Generated Files

Fields

files: HashMap<String, (String, f64)>

each files is saved in this hashmap where: the key is the name the parameter String is the source code generated the f64 is how much points that test is worth

Implementations

source

impl RustGeneratedFiles

source

pub async fn compile( self, path: Option<PathBuf>, ) -> Result<RustCompiled, CompileError>

Compiles each files creating a project in a temporary directory, or in path if specified