Struct rust_default::StatelessCLIPlugin
source · pub struct StatelessCLIPlugin;Trait Implementations
sourceimpl<S: ExecutorGlobalState> Plugin<S> for StatelessCLIPlugin
impl<S: ExecutorGlobalState> Plugin<S> for StatelessCLIPlugin
sourcefn desctiption(&self) -> &str
fn desctiption(&self) -> &str
Return a descriptionn of the Plugin. It should contain a list of the registered and activated Executors
sourceasync fn run(self, o: OrchestratorReference<S>, should_stop: Arc<Notify>)
async fn run(self, o: OrchestratorReference<S>, should_stop: Arc<Notify>)
Function called when the Plugin is runned (at the end of the init phase).
it takes an OrchestratorReference, which permit almost complete control over the orchestrator, and a shared Notify.
This notify should get called when a Plugin request an orchestrator shutdown.
sourceasync fn on_add<'a>(
&'a mut self,
_o: &'a mut Orchestrator<S>,
) -> Result<(), Box<dyn Error + Send + Sync + 'static>>
async fn on_add<'a>( &'a mut self, _o: &'a mut Orchestrator<S>, ) -> Result<(), Box<dyn Error + Send + Sync + 'static>>
When the plugin gets added to the Orchestrator, this function gets called.
It gives complete control on the unrunned executor.
It should be used to register/activate executor, add other Plugins, add Exercise (discouraged)…